==> muse_0.5.2.orig.tar.gz: muse-0.5.2/icons.cpp <==
//=========================================================
//  MusE
//  Linux Music Editor
//  $Id: icons.cpp,v 1.1 2002/01/30 14:54:03 muse Exp $
//
//  (C) Copyright 1999/2000 Werner Schweer (ws@seh.de)
//=========================================================

#include "globals.h"
#include <qpixmap.h>

#include "xpm/pointer.xpm"
#include "xpm/pencil.xpm"
#include "xpm/delete.xpm"
#include "xpm/play.xpm"
#include "xpm/record.xpm"
#include "xpm/record1.xpm"
#include "xpm/stop.xpm"
#include "xpm/start.xpm"
#include "xpm/fforward.xpm"
#include "xpm/frewind.xpm"
#include "xpm/punchin.xpm"
#include "xpm/punchout.xpm"
#include "xpm/punchin1.xpm"
#include "xpm/punchout1.xpm"
#include "xpm/loop1.xpm"
#include "xpm/loop.xpm"
#include "xpm/dot.xpm"
#include "xpm/doth.xpm"
#include "xpm/dot1.xpm"
#include "xpm/note.xpm"
#include "xpm/note1.xpm"
#include "xpm/stick.xpm"
#include "xpm/wave.xpm"
#include "xpm/cmark.xpm"
#include "xpm/lmark.xpm"
#include "xpm/rmark.xpm"
#include "xpm/cut.xpm"
#include "xpm/steprec.xpm"
#include "xpm/glue.xpm"
#include "xpm/draw.xpm"
#include "xpm/quant.xpm"
#include "xpm/fileprint.xpm"
#include "xpm/filesave.xpm"
#include "xpm/fileopen.xpm"
#include "xpm/fileprintS.xpm"
#include "xpm/filesaveS.xpm"
#include "xpm/fileopenS.xpm"
#include "xpm/master.xpm"
#include "xpm/filenew.xpm"
#include "xpm/filenewS.xpm"
#include "xpm/home.xpm"
#include "xpm/back.xpm"
#include "xpm/forward.xpm"
#include "xpm/mute.xpm"
#include "xpm/up.xpm"
#include "xpm/down.xpm"
#include "xpm/bold.xpm"
#include "xpm/italic.xpm"
#include "xpm/underlined.xpm"
#include "xpm/gv.xpm"
#include "xpm/midiin.xpm"
#include "xpm/sysex.xpm"
#include "xpm/ctrl.xpm"
#include "xpm/meta.xpm"
#include "xpm/pitch.xpm"
#include "xpm/cafter.xpm"
#include "xpm/pafter.xpm"
#include "xpm/flag.xpm"
#include "xpm/flagS.xpm"
#include "xpm/lock.xpm"
#include "xpm/toc.xpm"
#include "xpm/piano.xpm"
#include "xpm/pianoS.xpm"
#include "xpm/exitS.xpm"

#include "xpm/undo.xpm"
#include "xpm/redo.xpm"
#include "xpm/editcut.xpm"
#include "xpm/editcopy.xpm"
#include "xpm/editpaste.xpm"
#include "xpm/undoS.xpm"
#include "xpm/redoS.xpm"
#include "xpm/editcutS.xpm"
#include "xpm/editcopyS.xpm"
#include "xpm/editpasteS.xpm"

#include "xpm/scoreS.xpm"
#include "xpm/score.xpm"
#include "xpm/speaker.xpm"
#include "xpm/buttondown.xpm"
#include "xpm/configure.xpm"

QPixmap* pointerIcon;
QPixmap* pencilIcon;
QPixmap* deleteIcon;
QPixmap* punchinIcon;
QPixmap* punchoutIcon;
QPixmap* punchin1Icon;
QPixmap* punchout1Icon;
QPixmap* loopIcon;
QPixmap* loop1Icon;
QPixmap* playIcon;
QPixmap* recordIcon;
QPixmap* record1Icon;
QPixmap* stopIcon;
QPixmap* startIcon;
QPixmap* fforwardIcon;
QPixmap* frewindIcon;
QPixmap* dotIcon;
QPixmap* dothIcon;
QPixmap* dot1Icon;
QPixmap* note1Icon;
QPixmap* noteIcon;
QPixmap* stickIcon;
QPixmap* waveIcon;
QPixmap* markIcon[3];
QPixmap* cutIcon;
QPixmap* steprecIcon;
QPixmap* glueIcon;
QPixmap* drawIcon;
QPixmap* quantIcon;
QPixmap* printIcon;
QPixmap* printIconS;
QPixmap* openIcon;
QPixmap* saveIcon;
QPixmap* openIconS;
QPixmap* saveIconS;
QPixmap* masterIcon;
QPixmap* filenewIcon;
QPixmap* filenewIconS;
QPixmap* homeIcon;
QPixmap* backIcon;
QPixmap* forwardIcon;
QPixmap* muteIcon;
QPixmap* upIcon;
QPixmap* downIcon;
QPixmap* boldIcon;
QPixmap* italicIcon;
QPixmap* underlinedIcon;
QPixmap* gvIcon;
QPixmap* midiinIcon;
QPixmap* sysexIcon;
QPixmap* ctrlIcon;
QPixmap* metaIcon;
QPixmap* pitchIcon;
QPixmap* cafterIcon;
QPixmap* pafterIcon;
QPixmap* flagIcon;
QPixmap* flagIconS;
QPixmap* lockIcon;
QPixmap* tocIcon;
QPixmap* exitIconS;

QPixmap* undoIcon;
QPixmap* redoIcon;
QPixmap* undoIconS;
QPixmap* redoIconS;

QPixmap* speakerIcon;
QPixmap* buttondownIcon;
QPixmap* configureIcon;

QIconSet* pianoIconSet;
QIconSet* scoreIconSet;
QIconSet* editcutIconSet;
QIconSet* editcopyIconSet;
QIconSet* editpasteIconSet;

//---------------------------------------------------------
//   initIcons
//---------------------------------------------------------

void initIcons()
      {
      pointerIcon  = new QPixmap(pointer_xpm);
      pencilIcon   = new QPixmap(pencil_xpm);
      deleteIcon   = new QPixmap(delete_xpm);
      punchinIcon  = new QPixmap(punchin_xpm);
      punchoutIcon = new QPixmap(punchout_xpm);
      punchin1Icon = new QPixmap(punchin1_xpm);
      punchout1Icon = new QPixmap(punchout1_xpm);
      loopIcon     = new QPixmap(loop_xpm);
      loop1Icon    = new QPixmap(loop1_xpm);
      playIcon     = new QPixmap(play_xpm);
      recordIcon   = new QPixmap(record_xpm);
      record1Icon   = new QPixmap(record1_xpm);
      stopIcon     = new QPixmap(stop_xpm);
      startIcon    = new QPixmap(start_xpm);
      fforwardIcon = new QPixmap(fforward_xpm);
      frewindIcon  = new QPixmap(frewind_xpm);
      dotIcon      = new QPixmap(dot_xpm);
      dothIcon     = new QPixmap(doth_xpm);
      dot1Icon     = new QPixmap(dot1_xpm);
      noteIcon     = new QPixmap(note_xpm);
      note1Icon    = new QPixmap(note1_xpm);
      stickIcon    = new QPixmap(stick_xpm);
      waveIcon     = new QPixmap(wave_xpm);
      markIcon[0]  = new QPixmap(cmark_xpm);
      markIcon[1]  = new QPixmap(lmark_xpm);
      markIcon[2]  = new QPixmap(rmark_xpm);
      cutIcon      = new QPixmap(cut_xpm);
      steprecIcon  = new QPixmap(steprec_xpm);
      glueIcon     = new QPixmap(glue_xpm);
      drawIcon     = new QPixmap(draw_xpm);
      quantIcon    = new QPixmap(quant_xpm);
      saveIcon     = new QPixmap(filesave_xpm);
      printIcon    = new QPixmap(fileprint_xpm);
      openIcon     = new QPixmap(fileopen_xpm);
      saveIconS     = new QPixmap(filesaveS_xpm);
      printIconS    = new QPixmap(fileprintS_xpm);
      openIconS     = new QPixmap(fileopenS_xpm);
      masterIcon   = new QPixmap(master_xpm);
      filenewIcon  = new QPixmap(filenew_xpm);
      filenewIconS  = new QPixmap(filenewS_xpm);
      homeIcon     = new QPixmap(home_xpm);
      backIcon     = new QPixmap(back_xpm);
      forwardIcon  = new QPixmap(forward_xpm);
      muteIcon     = new QPixmap(mute_xpm);
      upIcon       = new QPixmap(up_xpm);
      downIcon     = new QPixmap(down_xpm);
      boldIcon     = new QPixmap(bold_xpm);
      italicIcon     = new QPixmap(italic_xpm);
      underlinedIcon = new QPixmap(underlined_xpm);
      gvIcon     = new QPixmap(gv_xpm);
      midiinIcon = new QPixmap(midiin_xpm);
      sysexIcon   = new QPixmap(sysex_xpm);
      ctrlIcon    = new QPixmap(ctrl_xpm);
      metaIcon    = new QPixmap(meta_xpm);
      pitchIcon   = new QPixmap(pitch_xpm);
      cafterIcon  = new QPixmap(cafter_xpm);
      pafterIcon  = new QPixmap(pafter_xpm);
      flagIcon    = new QPixmap(flag_xpm);
      flagIconS   = new QPixmap(flagS_xpm);
      lockIcon    = new QPixmap(lock_xpm);
      tocIcon     = new QPixmap(toc_xpm);
      exitIconS   = new QPixmap(exitS_xpm);

      undoIcon     = new QPixmap(undo_xpm);
      redoIcon     = new QPixmap(redo_xpm);
      undoIconS    = new QPixmap(undoS_xpm);
      redoIconS    = new QPixmap(redoS_xpm);

      speakerIcon    = new QPixmap(speaker_xpm);
      buttondownIcon = new QPixmap(buttondown_xpm);
      configureIcon  = new QPixmap(configure_xpm);

      pianoIconSet     = new QIconSet(QPixmap(pianoS_xpm), QPixmap(piano_xpm));
      scoreIconSet     = new QIconSet(QPixmap(scoreS_xpm), QPixmap(score_xpm));
      editcutIconSet   = new QIconSet(QPixmap(editcutS_xpm), QPixmap(editcut_xpm));
      editcopyIconSet  = new QIconSet(QPixmap(editcopyS_xpm), QPixmap(editcopy_xpm));
      editpasteIconSet = new QIconSet(QPixmap(editpasteS_xpm), QPixmap(editpaste_xpm));
      }

==> muse_0.6.3.orig.tar.gz: muse-0.6.3/icons.cpp <==
//=========================================================
//  MusE
//  Linux Music Editor
//  $Id: icons.cpp,v 1.1.1.1 2003/10/29 10:05:12 wschweer Exp $
//
//  (C) Copyright 1999/2000 Werner Schweer (ws@seh.de)
//=========================================================

#include "globals.h"
#include <qpixmap.h>

#include "xpm/pointer.xpm"
#include "xpm/pencil.xpm"
#include "xpm/delete.xpm"
#include "xpm/play.xpm"
#include "xpm/record.xpm"
#include "xpm/record1.xpm"
#include "xpm/stop.xpm"
#include "xpm/start.xpm"
#include "xpm/fforward.xpm"
#include "xpm/frewind.xpm"
#include "xpm/punchin.xpm"
#include "xpm/punchout.xpm"
#include "xpm/punchin1.xpm"
#include "xpm/punchout1.xpm"
#include "xpm/loop1.xpm"
#include "xpm/loop.xpm"
#include "xpm/dot.xpm"
#include "xpm/doth.xpm"
#include "xpm/dot1.xpm"
#include "xpm/note.xpm"
#include "xpm/note1.xpm"
#include "xpm/stick.xpm"
#include "xpm/wave.xpm"
#include "xpm/cmark.xpm"
#include "xpm/lmark.xpm"
#include "xpm/rmark.xpm"
#include "xpm/cut.xpm"
#include "xpm/steprec.xpm"
#include "xpm/glue.xpm"
#include "xpm/draw.xpm"
#include "xpm/quant.xpm"
#include "xpm/fileprint.xpm"
#include "xpm/filesave.xpm"
#include "xpm/fileopen.xpm"
#include "xpm/fileprintS.xpm"
#include "xpm/filesaveS.xpm"
#include "xpm/fileopenS.xpm"
#include "xpm/master.xpm"
#include "xpm/filenew.xpm"
#include "xpm/filenewS.xpm"
#include "xpm/home.xpm"
#include "xpm/back.xpm"
#include "xpm/forward.xpm"
#include "xpm/mute.xpm"
#include "xpm/up.xpm"
#include "xpm/down.xpm"
#include "xpm/bold.xpm"
#include "xpm/italic.xpm"
#include "xpm/underlined.xpm"
#include "xpm/gv.xpm"
#include "xpm/midiin.xpm"
#include "xpm/sysex.xpm"
#include "xpm/ctrl.xpm"
#include "xpm/meta.xpm"
#include "xpm/pitch.xpm"
#include "xpm/cafter.xpm"
#include "xpm/pafter.xpm"
#include "xpm/flag.xpm"
#include "xpm/flagS.xpm"
#include "xpm/lock.xpm"
#include "xpm/toc.xpm"
#include "xpm/piano.xpm"
#include "xpm/pianoS.xpm"
#include "xpm/exitS.xpm"

#include "xpm/undo.xpm"
#include "xpm/redo.xpm"
#include "xpm/editcut.xpm"
#include "xpm/editcopy.xpm"
#include "xpm/editpaste.xpm"
#include "xpm/undoS.xpm"
#include "xpm/redoS.xpm"
#include "xpm/editcutS.xpm"
#include "xpm/editcopyS.xpm"
#include "xpm/editpasteS.xpm"
#include "xpm/editmute.xpm"
#include "xpm/editmuteS.xpm"

#include "xpm/scoreS.xpm"
#include "xpm/score.xpm"
#include "xpm/speaker.xpm"
#include "xpm/buttondown.xpm"
#include "xpm/configure.xpm"
#include "xpm/panic.xpm"

#include "xpm/recordonbutton.xpm"
#include "xpm/recordoffbutton.xpm"
#include "xpm/solobutton.xpm"
#include "xpm/newmutebutton.xpm"
#include "xpm/exit.xpm"

#include "xpm/reddot.xpm"
#include "xpm/greendot.xpm"
#include "xpm/darkreddot.xpm"
#include "xpm/darkgreendot.xpm"
#include "xpm/bluedot.xpm"
#include "xpm/graydot.xpm"
#include "xpm/off.xpm"

QPixmap* exitIcon;
QPixmap* recordonIcon;
QPixmap* recordoffIcon;
QPixmap* newmuteIcon;
QPixmap* soloIcon;

QPixmap* pointerIcon;
QPixmap* pencilIcon;
QPixmap* deleteIcon;
QPixmap* punchinIcon;
QPixmap* punchoutIcon;
QPixmap* punchin1Icon;
QPixmap* punchout1Icon;
QPixmap* loopIcon;
QPixmap* loop1Icon;
QPixmap* playIcon;
QPixmap* recordIcon;
QPixmap* record1Icon;
QPixmap* stopIcon;
QPixmap* startIcon;
QPixmap* fforwardIcon;
QPixmap* frewindIcon;
QPixmap* dotIcon;
QPixmap* dothIcon;
QPixmap* dot1Icon;
QPixmap* note1Icon;
QPixmap* noteIcon;
QPixmap* stickIcon;
QPixmap* waveIcon;
QPixmap* markIcon[3];
QPixmap* cutIcon;
QPixmap* steprecIcon;
QPixmap* glueIcon;
QPixmap* drawIcon;
QPixmap* quantIcon;
QPixmap* printIcon;
QPixmap* printIconS;
QPixmap* openIcon;
QPixmap* saveIcon;
QPixmap* openIconS;
QPixmap* saveIconS;
QPixmap* masterIcon;
QPixmap* filenewIcon;
QPixmap* filenewIconS;
QPixmap* homeIcon;
QPixmap* backIcon;
QPixmap* forwardIcon;
QPixmap* muteIcon;
QPixmap* upIcon;
QPixmap* downIcon;
QPixmap* boldIcon;
QPixmap* italicIcon;
QPixmap* underlinedIcon;
QPixmap* gvIcon;
QPixmap* midiinIcon;
QPixmap* sysexIcon;
QPixmap* ctrlIcon;
QPixmap* metaIcon;
QPixmap* pitchIcon;
QPixmap* cafterIcon;
QPixmap* pafterIcon;
QPixmap* flagIcon;
QPixmap* flagIconS;
QPixmap* lockIcon;
QPixmap* tocIcon;
QPixmap* exitIconS;

QPixmap* undoIcon;
QPixmap* redoIcon;
QPixmap* undoIconS;
QPixmap* redoIconS;

QPixmap* speakerIcon;
QPixmap* buttondownIcon;
QPixmap* configureIcon;

QPixmap* editmuteIcon;
QPixmap* editmuteSIcon;
QPixmap* panicIcon;

QIconSet* pianoIconSet;
QIconSet* scoreIconSet;
QIconSet* editcutIconSet;
QIconSet* editmuteIconSet;
QIconSet* editcopyIconSet;
QIconSet* editpasteIconSet;

QPixmap* greendotIcon;
QPixmap* darkgreendotIcon;
QPixmap* reddotIcon;
QPixmap* darkreddotIcon;
QPixmap* graydotIcon;
QPixmap* bluedotIcon;
QPixmap* offIcon;

//---------------------------------------------------------
//   initIcons
//---------------------------------------------------------

void initIcons()
      {
      pointerIcon  = new QPixmap(pointer_xpm);
      pencilIcon   = new QPixmap(pencil_xpm);
      deleteIcon   = new QPixmap(delete_xpm);
      punchinIcon  = new QPixmap(punchin_xpm);
      punchoutIcon = new QPixmap(punchout_xpm);
      punchin1Icon = new QPixmap(punchin1_xpm);
      punchout1Icon = new QPixmap(punchout1_xpm);
      loopIcon     = new QPixmap(loop_xpm);
      loop1Icon    = new QPixmap(loop1_xpm);
      playIcon     = new QPixmap(play_xpm);
      recordIcon   = new QPixmap(record_xpm);
      record1Icon   = new QPixmap(record1_xpm);
      stopIcon     = new QPixmap(stop_xpm);
      startIcon    = new QPixmap(start_xpm);
      fforwardIcon = new QPixmap(fforward_xpm);
      frewindIcon  = new QPixmap(frewind_xpm);
      dotIcon      = new QPixmap(dot_xpm);
      dothIcon     = new QPixmap(doth_xpm);
      dot1Icon     = new QPixmap(dot1_xpm);
      noteIcon     = new QPixmap(note_xpm);
      note1Icon    = new QPixmap(note1_xpm);
      stickIcon    = new QPixmap(stick_xpm);
      waveIcon     = new QPixmap(wave_xpm);
      markIcon[0]  = new QPixmap(cmark_xpm);
      markIcon[1]  = new QPixmap(lmark_xpm);
      markIcon[2]  = new QPixmap(rmark_xpm);
      cutIcon      = new QPixmap(cut_xpm);
      steprecIcon  = new QPixmap(steprec_xpm);
      glueIcon     = new QPixmap(glue_xpm);
      drawIcon     = new QPixmap(draw_xpm);
      quantIcon    = new QPixmap(quant_xpm);
      saveIcon     = new QPixmap(filesave_xpm);
      printIcon    = new QPixmap(fileprint_xpm);
      openIcon     = new QPixmap(fileopen_xpm);
      saveIconS     = new QPixmap(filesaveS_xpm);
      printIconS    = new QPixmap(fileprintS_xpm);
      openIconS     = new QPixmap(fileopenS_xpm);
      masterIcon   = new QPixmap(master_xpm);
      filenewIcon  = new QPixmap(filenew_xpm);
      filenewIconS  = new QPixmap(filenewS_xpm);
      homeIcon     = new QPixmap(home_xpm);
      backIcon     = new QPixmap(back_xpm);
      forwardIcon  = new QPixmap(forward_xpm);
      muteIcon     = new QPixmap(mute_xpm);
      upIcon       = new QPixmap(up_xpm);
      downIcon     = new QPixmap(down_xpm);
      boldIcon     = new QPixmap(bold_xpm);
      italicIcon     = new QPixmap(italic_xpm);
      underlinedIcon = new QPixmap(underlined_xpm);
      gvIcon     = new QPixmap(gv_xpm);
      midiinIcon = new QPixmap(midiin_xpm);
      sysexIcon   = new QPixmap(sysex_xpm);
      ctrlIcon    = new QPixmap(ctrl_xpm);
      metaIcon    = new QPixmap(meta_xpm);
      pitchIcon   = new QPixmap(pitch_xpm);
      cafterIcon  = new QPixmap(cafter_xpm);
      pafterIcon  = new QPixmap(pafter_xpm);
      flagIcon    = new QPixmap(flag_xpm);
      flagIconS   = new QPixmap(flagS_xpm);
      lockIcon    = new QPixmap(lock_xpm);
      tocIcon     = new QPixmap(toc_xpm);
      exitIconS   = new QPixmap(exitS_xpm);

      undoIcon     = new QPixmap(undo_xpm);
      redoIcon     = new QPixmap(redo_xpm);
      undoIconS    = new QPixmap(undoS_xpm);
      redoIconS    = new QPixmap(redoS_xpm);

      speakerIcon    = new QPixmap(speaker_xpm);
      buttondownIcon = new QPixmap(buttondown_xpm);
      configureIcon  = new QPixmap(configure_xpm);

      editmuteIcon  = new QPixmap(editmute_xpm);
      editmuteSIcon = new QPixmap(editmuteS_xpm);
      panicIcon  = new QPixmap(panic_xpm);

      pianoIconSet     = new QIconSet(QPixmap(pianoS_xpm), QPixmap(piano_xpm));
      scoreIconSet     = new QIconSet(QPixmap(scoreS_xpm), QPixmap(score_xpm));
      editcutIconSet   = new QIconSet(QPixmap(editcutS_xpm), QPixmap(editcut_xpm));
      editcopyIconSet  = new QIconSet(QPixmap(editcopyS_xpm), QPixmap(editcopy_xpm));
      editpasteIconSet = new QIconSet(QPixmap(editpasteS_xpm), QPixmap(editpaste_xpm));
      editmuteIconSet  = new QIconSet(QPixmap(editmuteS_xpm), QPixmap(editmute_xpm));

      exitIcon       = new QPixmap(exit_xpm);
      recordonIcon   = new QPixmap(recordonbutton_xpm);
      recordoffIcon  = new QPixmap(recordoffbutton_xpm);
      newmuteIcon       = new QPixmap(newmutebutton_xpm);
      soloIcon          = new QPixmap(solobutton_xpm);

      greendotIcon      = new QPixmap(greendot_xpm);
      darkgreendotIcon  = new QPixmap(darkgreendot_xpm);
      reddotIcon        = new QPixmap(reddot_xpm);
      bluedotIcon       = new QPixmap(bluedot_xpm);
      graydotIcon       = new QPixmap(graydot_xpm);
      darkreddotIcon    = new QPixmap(darkreddot_xpm);
      offIcon           = new QPixmap(off_xpm);
      }
